==> ejc-scientific-impl-3.0.0-20250306.094721-39-sources.jar: com/ejianc/business/scientific/sci/bean/SciProjectChangeUserHourEntity.java <==
package com.ejianc.business.scientific.sci.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 科研项目立项-变更-项目成员-计划工时
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_project_change_user_hour")
public class SciProjectChangeUserHourEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="user_id")
    private Long userId; // 人员主键
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="plan_year")
    private Date planYear; // 年度
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="plan_hour")
    private BigDecimal planHour; // 计划工时(月)
    @TableField(value="source_id")
    private Long sourceId; // 来源主键
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public Date getPlanYear() {
        return planYear;
    }

    public void setPlanYear(Date planYear) {
        this.planYear = planYear;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getPlanHour() {
        return planHour;
    }

    public void setPlanHour(BigDecimal planHour) {
        this.planHour = planHour;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}

==> ejc-scientific-impl-3.0.0-20250829.061142-90-sources.jar: com/ejianc/business/scientific/sci/bean/SciProjectChangeUserHourEntity.java <==
package com.ejianc.business.scientific.sci.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 科研项目立项-变更-项目成员-计划工时
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_project_change_user_hour")
public class SciProjectChangeUserHourEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="user_id")
    private Long userId; // 人员主键
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="plan_year")
    private String planYear; // 年度
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="plan_hour")
    private BigDecimal planHour; // 计划工时(月)
    @TableField(value="source_id")
    private Long sourceId; // 来源主键
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getPlanYear() {
        return planYear;
    }

    public void setPlanYear(String planYear) {
        this.planYear = planYear;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getPlanHour() {
        return planHour;
    }

    public void setPlanHour(BigDecimal planHour) {
        this.planHour = planHour;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}
